Saltypie - salt-api wrapper and state return parser.
====================================================

Installation
============

.. code-block:: bash
   pip install saltypie


Documentation
=============

https://cathaldallan.gitlab.io/saltypie/